Python Wires Change Log
=======================

.. marker-start-of-change-log

.. towncrier release notes start

Wires 18.1.0
------------

Enhancements
^^^^^^^^^^^^

- Initial public release. (`#100
  <https://github.com/tmontes/python-wires/issues/100>`_)


